@@ -3,8 +3,9 @@ from __future__ import annotations
 import abc
 import sys
 import typing as t
+from enum import Enum
 
-from pydantic import Field
+from pydantic import Field, root_validator
 
 from sqlmesh.core import engine_adapter
 from sqlmesh.core.config.base import BaseConfig
@@ -13,6 +14,7 @@ from sqlmesh.core.config.common import (
     http_headers_validator,
 )
 from sqlmesh.core.engine_adapter import EngineAdapter
+from sqlmesh.utils.errors import ConfigError
 
 if sys.version_info >= (3, 9):
     from typing import Annotated, Literal
@@ -89,21 +91,24 @@ class SnowflakeConnectionConfig(_ConnectionConfig):
     """Configuration for the Snowflake connection.
 
     Args:
+        account: The Snowflake account name.
         user: The Snowflake username.
         password: The Snowflake password.
-        account: The Snowflake account name.
         warehouse: The optional warehouse name.
         database: The optional database name.
         role: The optional role name.
         concurrent_tasks: The maximum number of tasks that can use this connection concurrently.
+        authenticator: The optional authenticator name. Defaults to username/password authentication ("snowflake").
+                       Options: https://github.com/snowflakedb/snowflake-connector-python/blob/e937591356c067a77f34a0a42328907fda792c23/src/snowflake/connector/network.py#L178-L183
     """
 
-    user: str
-    password: str
     account: str
+    user: t.Optional[str]
+    password: t.Optional[str]
     warehouse: t.Optional[str]
     database: t.Optional[str]
     role: t.Optional[str]
+    authenticator: t.Optional[str]
 
     concurrent_tasks: int = 4
 
@@ -111,9 +116,20 @@ class SnowflakeConnectionConfig(_ConnectionConfig):
 
     _concurrent_tasks_validator = concurrent_tasks_validator
 
+    @root_validator()
+    def _validate_authenticator(
+        cls, fields: t.Dict[str, t.Optional[str]]
+    ) -> t.Dict[str, t.Optional[str]]:
+        auth = fields.get("authenticator")
+        user = fields.get("user")
+        password = fields.get("password")
+        if not auth and (not user or not password):
+            raise ConfigError("User and password must be provided if using default authentication")
+        return fields
+
     @property
     def _connection_kwargs_keys(self) -> t.Set[str]:
-        return {"user", "password", "account", "warehouse", "database", "role"}
+        return {"user", "password", "account", "warehouse", "database", "role", "authenticator"}
 
     @property
     def _engine_adapter(self) -> t.Type[EngineAdapter]:
@@ -321,13 +337,33 @@ class DatabricksConnectionConfig(_ConnectionConfig):
         return {}
 
 
+class BigQueryConnectionMethod(str, Enum):
+    OAUTH = "oauth"
+    OAUTH_SECRETS = "oauth-secrets"
+    SERVICE_ACCOUNT = "service-account"
+    SERVICE_ACCOUNT_JSON = "service-account-json"
+
+
 class BigQueryConnectionConfig(_ConnectionConfig):
     """
     BigQuery Connection Configuration.
-
-    TODO: Need to update to support all the different authentication options
     """
 
+    method: BigQueryConnectionMethod = BigQueryConnectionMethod.OAUTH
+
+    project: t.Optional[str] = None
+    location: t.Optional[str] = None
+    # Keyfile Auth
+    keyfile: t.Optional[str] = None
+    keyfile_json: t.Optional[t.Dict[str, t.Any]] = None
+    # Oath Secret Auth
+    token: t.Optional[str] = None
+    refresh_token: t.Optional[str] = None
+    client_id: t.Optional[str] = None
+    client_secret: t.Optional[str] = None
+    token_uri: t.Optional[str] = None
+    scopes: t.Tuple[str, ...] = ("https://www.googleapis.com/auth/bigquery",)
+
     concurrent_tasks: int = 4
 
     type_: Literal["bigquery"] = Field(alias="type", default="bigquery")
@@ -340,6 +376,45 @@ class BigQueryConnectionConfig(_ConnectionConfig):
     def _engine_adapter(self) -> t.Type[EngineAdapter]:
         return engine_adapter.BigQueryEngineAdapter
 
+    @property
+    def _static_connection_kwargs(self) -> t.Dict[str, t.Any]:
+        """The static connection kwargs for this connection"""
+        import google.auth
+        from google.api_core import client_info
+        from google.oauth2 import credentials, service_account
+
+        if self.method == BigQueryConnectionMethod.OAUTH:
+            creds, _ = google.auth.default(scopes=self.scopes)
+        elif self.method == BigQueryConnectionMethod.SERVICE_ACCOUNT:
+            creds = service_account.Credentials.from_service_account_file(
+                self.keyfile, scopes=self.scopes
+            )
+        elif self.method == BigQueryConnectionMethod.SERVICE_ACCOUNT_JSON:
+            creds = service_account.Credentials.from_service_account_info(
+                self.keyfile_json, scopes=self.scopes
+            )
+        elif self.method == BigQueryConnectionMethod.OAUTH_SECRETS:
+            creds = credentials.Credentials(
+                token=self.token,
+                refresh_token=self.refresh_token,
+                client_id=self.client_id,
+                client_secret=self.client_secret,
+                token_uri=self.token_uri,
+                scopes=self.scopes,
+            )
+        else:
+            raise ConfigError("Invalid BigQuery Connection Method")
+        client = google.cloud.bigquery.Client(
+            project=self.project,
+            credentials=creds,
+            location=self.location,
+            client_info=client_info.ClientInfo(user_agent="sqlmesh"),
+        )
+
+        return {
+            "client": client,
+        }
+
     @property
     def _connection_factory(self) -> t.Callable:
         from google.cloud.bigquery.dbapi import connect
