@@ -5,12 +5,14 @@ from functools import reduce
 from string import Template
 
 import sqlglot
+from jinja2 import Environment
 from sqlglot import Generator, exp
 from sqlglot.executor.env import ENV
 from sqlglot.executor.python import Python
 from sqlglot.helper import csv, ensure_collection
 
 from sqlmesh.core.dialect import (
+    Jinja,
     MacroDef,
     MacroFunc,
     MacroSQL,
@@ -19,6 +21,7 @@ from sqlmesh.core.dialect import (
 )
 from sqlmesh.utils import UniqueKeyDict, registry_decorator
 from sqlmesh.utils.errors import MacroEvalError, SQLMeshError
+from sqlmesh.utils.jinja import JinjaMacroRegistry
 from sqlmesh.utils.metaprogramming import Executable, prepare_env, print_exception
 
 
@@ -90,12 +93,18 @@ class MacroEvaluator:
         python_env: Serialized Python environment.
     """
 
-    def __init__(self, dialect: str = "", python_env: t.Optional[t.Dict[str, Executable]] = None):
+    def __init__(
+        self,
+        dialect: str = "",
+        python_env: t.Optional[t.Dict[str, Executable]] = None,
+        jinja_env: t.Optional[Environment] = None,
+    ):
         self.dialect = dialect
         self.generator = MacroDialect().generator()
         self.locals: t.Dict[str, t.Any] = {}
         self.env = {**ENV, "self": self}
         self.python_env = python_env or {}
+        self._jinja_env: t.Optional[Environment] = jinja_env
         self.macros = {normalize_macro_name(k): v.func for k, v in macro.get_registry().items()}
         prepare_env(self.python_env, self.env)
         for k, v in self.python_env.items():
@@ -117,11 +126,16 @@ class MacroEvaluator:
             raise MacroEvalError(f"Error trying to eval macro.") from e
 
     def transform(self, query: exp.Expression) -> exp.Expression | t.List[exp.Expression] | None:
-        query = query.transform(
-            lambda node: exp.convert(_norm_env_value(self.locals[node.name]))
-            if isinstance(node, MacroVar)
-            else node
-        )
+        def _transform_node(node: exp.Expression) -> exp.Expression:
+            if isinstance(node, MacroVar):
+                return exp.convert(_norm_env_value(self.locals[node.name]))
+            elif node.is_string:
+                node.set("this", self.jinja_env.from_string(node.this).render())
+                return node
+            else:
+                return node
+
+        query = query.transform(_transform_node)
 
         def evaluate_macros(
             node: exp.Expression,
@@ -137,6 +151,8 @@ class MacroEvaluator:
 
         if isinstance(transformed, list):
             return [self.parse_one(node.sql(dialect=self.dialect)) for node in transformed]
+        elif isinstance(transformed, Jinja):
+            return transformed
         elif isinstance(transformed, exp.Expression):
             return self.parse_one(transformed.sql(dialect=self.dialect))
 
@@ -206,6 +222,14 @@ class MacroEvaluator:
         """
         return sqlglot.maybe_parse(sql, dialect=self.dialect, into=into, **opts)
 
+    @property
+    def jinja_env(self) -> Environment:
+        if not self._jinja_env:
+            jinja_env_methods = {**self.locals, **self.env}
+            del jinja_env_methods["self"]
+            self._jinja_env = JinjaMacroRegistry().build_environment(**jinja_env_methods)
+        return self._jinja_env
+
 
 class macro(registry_decorator):
     """Specifies a function is a macro and registers it the global MACROS registry.
