@@ -1,3 +1,5 @@
+from datetime import timedelta
+
 import pytest
 from pytest_mock.plugin import MockerFixture
 from sqlglot import parse_one
@@ -12,7 +14,7 @@ from sqlmesh.core.snapshot import (
     SnapshotFingerprint,
 )
 from sqlmesh.utils.dag import DAG
-from sqlmesh.utils.date import to_datetime, to_timestamp
+from sqlmesh.utils.date import to_date, to_datetime, to_timestamp
 from sqlmesh.utils.errors import PlanError
 
 
@@ -60,7 +62,7 @@ def test_forward_only_dev(make_snapshot, mocker: MockerFixture):
         )
     )
 
-    expected_start = "2022-01-01"
+    expected_start = to_datetime("2022-01-01")
     expected_end = to_datetime("2022-01-02")
 
     dag = DAG[str]({"a": set()})
@@ -73,7 +75,7 @@ def test_forward_only_dev(make_snapshot, mocker: MockerFixture):
 
     state_reader_mock = mocker.Mock()
 
-    yesterday_ds_mock = mocker.patch("sqlmesh.core.plan.definition.yesterday_ds")
+    yesterday_ds_mock = mocker.patch("sqlmesh.core.scheduler.yesterday")
     yesterday_ds_mock.return_value = expected_start
 
     now_ds_mock = mocker.patch("sqlmesh.core.plan.definition.now")
@@ -87,7 +89,7 @@ def test_forward_only_dev(make_snapshot, mocker: MockerFixture):
     assert plan.end == expected_end
 
     yesterday_ds_mock.assert_called_once()
-    now_ds_mock.assert_called_once()
+    now_ds_mock.call_count == 2
 
 
 def test_forward_only_plan_new_models_not_allowed(make_snapshot, mocker: MockerFixture):
@@ -377,3 +379,39 @@ def test_auto_categorization(make_snapshot, mocker: MockerFixture):
 
     assert updated_snapshot.version == updated_snapshot.fingerprint.to_version()
     assert updated_snapshot.change_category == SnapshotChangeCategory.BREAKING
+
+
+def test_end_from_missing_instead_of_now(make_snapshot, mocker: MockerFixture):
+    snapshot_a = make_snapshot(
+        SqlModel(
+            name="a",
+            query=parse_one("select 1, ds"),
+            kind=IncrementalByTimeRangeKind(time_column="ds"),
+        )
+    )
+
+    expected_start = to_datetime("2022-01-01")
+    end_date = to_datetime("2022-01-03")
+    expected_end = to_date(end_date) - timedelta(days=1)
+    now = to_datetime("2022-01-30")
+
+    dag = DAG[str]({"a": set()})
+
+    context_diff_mock = mocker.Mock()
+    context_diff_mock.snapshots = {"a": snapshot_a}
+    context_diff_mock.added = {}
+    context_diff_mock.modified_snapshots = {}
+    context_diff_mock.new_snapshots = {snapshot_a.snapshot_id: snapshot_a}
+
+    state_reader_mock = mocker.Mock()
+
+    now_ds_mock = mocker.patch("sqlmesh.core.scheduler.now")
+    now_ds_mock.return_value = now
+    state_reader_mock.missing_intervals.return_value = {
+        snapshot_a: [(to_timestamp(expected_start), to_timestamp(end_date))]
+    }
+
+    plan = Plan(context_diff_mock, dag, state_reader_mock, is_dev=True)
+
+    assert plan.start == to_timestamp(expected_start)
+    assert plan.end == expected_end
