@@ -4,12 +4,14 @@ from pathlib import Path
 import pytest
 from _pytest.monkeypatch import MonkeyPatch
 from pytest_mock.plugin import MockerFixture
-from sqlglot import exp, parse, parse_one
+from sqlglot import exp, parse, parse_one, to_column
 
 from sqlmesh.core.config import AutoCategorizationMode, CategorizerConfig
 from sqlmesh.core.model import (
     IncrementalByTimeRangeKind,
     Model,
+    ModelKind,
+    ModelKindName,
     SeedKind,
     SqlModel,
     create_seed_model,
@@ -51,6 +53,20 @@ def model():
     )
 
 
+@pytest.fixture
+def full_refresh_model():
+    return SqlModel(
+        name="fr_model",
+        kind=ModelKind(name=ModelKindName.FULL),
+        owner="owner",
+        dialect="spark",
+        cron="1 0 * * *",
+        batch_size=30,
+        start="2020-01-01",
+        query=parse_one("SELECT @EACH([1, 2], x -> x), ds FROM parent.tbl"),
+    )
+
+
 @pytest.fixture
 def snapshot(
     model: Model,
@@ -70,6 +86,25 @@ def snapshot(
     return snapshot
 
 
+@pytest.fixture
+def full_refresh_snapshot(
+    full_refresh_model: Model,
+    parent_model: Model,
+    monkeypatch: MonkeyPatch,
+    mocker: MockerFixture,
+    make_snapshot,
+):
+    mock = mocker.Mock()
+    mock.return_value = to_datetime("2022-09-23T00:12:53+00:00")
+    monkeypatch.setattr("sqlmesh.utils.date.now", mock)
+    full_refresh_snapshot = make_snapshot(
+        full_refresh_model,
+        models={parent_model.name: parent_model, full_refresh_model.name: full_refresh_model},
+    )
+    full_refresh_snapshot.version = full_refresh_snapshot.fingerprint
+    return full_refresh_snapshot
+
+
 def test_json(snapshot: Snapshot):
     assert json.loads(snapshot.json()) == {
         "created_ts": 1663891973000,
@@ -151,11 +186,11 @@ def test_add_interval(snapshot: Snapshot, make_snapshot):
     ]
     snapshot.add_interval("2019-01-01 00:00:00", "2020-01-31 00:00:01")
     assert snapshot.intervals == [
-        (to_timestamp("2019-01-01"), to_timestamp("2020-02-01")),
+        (to_timestamp("2019-01-01"), to_timestamp("2020-01-31")),
     ]
-    snapshot.add_interval("2018-12-31 23:59:59", "2020-01-31 00:00:01")
+    snapshot.add_interval("2018-12-31 23:59:59", "2020-01-31 12:00:01")
     assert snapshot.intervals == [
-        (to_timestamp("2018-12-31"), to_timestamp("2020-02-01")),
+        (to_timestamp("2018-12-31"), to_timestamp("2020-01-31")),
     ]
 
     new_snapshot = make_snapshot(snapshot.model)
@@ -207,6 +242,34 @@ def test_missing_intervals(snapshot: Snapshot):
     ]
 
 
+def test_missing_interval_latest(
+    full_refresh_snapshot: Snapshot, monkeypatch: MonkeyPatch, mocker: MockerFixture
+):
+    mock = mocker.Mock()
+    mock.return_value = to_datetime("2020-01-05T00:12:53+00:00")
+    monkeypatch.setattr("sqlmesh.core.snapshot.definition.now", mock)
+    full_refresh_snapshot.add_interval("2020-01-01", "2020-01-01")
+    assert full_refresh_snapshot.missing_intervals("2020-01-01", "2020-01-01", "2020-01-01") == []
+    assert full_refresh_snapshot.missing_intervals("2020-01-02", "2020-01-02", "2020-01-02") == [
+        (to_timestamp("2020-01-02"), to_timestamp("2020-01-03"))
+    ]
+    assert full_refresh_snapshot.missing_intervals("2020-01-02", "2020-01-03", "2020-01-03") == [
+        (to_timestamp("2020-01-03"), to_timestamp("2020-01-04"))
+    ]
+    assert full_refresh_snapshot.missing_intervals("2020-01-02", "2020-01-03", "2020-01-04") == [
+        (to_timestamp("2020-01-04"), to_timestamp("2020-01-05"))
+    ]
+    assert full_refresh_snapshot.missing_intervals(
+        "2020-01-02", "2020-01-03", "2020-01-03 01:00:00"
+    ) == [(to_timestamp("2020-01-02"), to_timestamp("2020-01-03"))]
+    assert full_refresh_snapshot.missing_intervals(
+        "2020-01-02", "2020-01-03", "2020-01-04 23:59:59"
+    ) == [(to_timestamp("2020-01-03"), to_timestamp("2020-01-04"))]
+    assert full_refresh_snapshot.missing_intervals("2020-01-02", "2020-01-03") == [
+        (to_timestamp("2020-01-04"), to_timestamp("2020-01-05"))
+    ]
+
+
 def test_remove_intervals(snapshot: Snapshot):
     snapshot.add_interval("2020-01-01", "2020-01-01")
     snapshot.remove_interval("2020-01-01", "2020-01-01")
@@ -356,6 +419,16 @@ def test_fingerprint_jinja_macros(model: Model):
     assert updated_fingerprint.metadata_hash == original_fingerprint.metadata_hash
 
 
+def test_fingerprint_builtin_audits(model: Model, parent_model: Model):
+    fingerprint = fingerprint_from_model(model, models={})
+
+    model = SqlModel.parse_obj(
+        {**model.dict(), "audits": [("unique_values", {"columns": exp.convert([to_column("a")])})]}
+    )
+    new_fingerprint = fingerprint_from_model(model, models={})
+    assert new_fingerprint != fingerprint
+
+
 def test_stamp(model: Model):
     original_fingerprint = fingerprint_from_model(model, models={})
 
