@@ -3,7 +3,6 @@ from pathlib import Path
 import agate
 import pytest
 from dbt.exceptions import CompilationError
-from pytest_mock.plugin import MockerFixture
 from sqlglot import exp, parse_one
 
 from sqlmesh.core.context import Context, ExecutionContext
@@ -27,11 +26,6 @@ from sqlmesh.dbt.target import DuckDbConfig
 from sqlmesh.utils.errors import ConfigError, MacroEvalError
 
 
-@pytest.fixture()
-def sushi_dbt_project(mocker: MockerFixture) -> Project:
-    return Project.load(DbtContext(project_root=Path("examples/sushi_dbt")))
-
-
 def test_model_name():
     assert ModelConfig(target_schema="foo", path="models/bar.sql").model_name == "foo.bar"
     assert (
@@ -219,9 +213,9 @@ def test_config_containing_jinja():
 
 
 @pytest.mark.parametrize("model", ["sushi.waiters", "sushi.waiter_names"])
-def test_hooks(capsys, sushi_dbt_context: Context, model: str):
-    waiters = sushi_dbt_context.models[model]
-    execution_context = ExecutionContext(sushi_dbt_context.engine_adapter, {}, False)
+def test_hooks(capsys, sushi_test_dbt_context: Context, model: str):
+    waiters = sushi_test_dbt_context.models[model]
+    execution_context = ExecutionContext(sushi_test_dbt_context.engine_adapter, {}, False)
     capsys.readouterr()
 
     waiters.run_pre_hooks(execution_context)
@@ -231,8 +225,8 @@ def test_hooks(capsys, sushi_dbt_context: Context, model: str):
     assert "post-hook" in capsys.readouterr().out
 
 
-def test_target_jinja(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_target_jinja(sushi_test_project: Project):
+    context = sushi_test_project.context
 
     assert context.render("{{ target.name }}") == "in_memory"
     assert context.render("{{ target.schema }}") == "sushi"
@@ -240,41 +234,41 @@ def test_target_jinja(sushi_dbt_project: Project):
     assert context.render("{{ target.profile_name }}") == "sushi"
 
 
-def test_project_name_jinja(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_project_name_jinja(sushi_test_project: Project):
+    context = sushi_test_project.context
     assert context.render("{{ project_name }}") == "sushi"
 
 
-def test_schema_jinja(sushi_dbt_project: Project):
+def test_schema_jinja(sushi_test_project: Project):
     model_config = ModelConfig(target_schema="sushi", sql="SELECT 1 AS one FROM {{ schema }}")
-    context = sushi_dbt_project.context
+    context = sushi_test_project.context
     model_config.to_sqlmesh(context).render_query().sql() == "SELECT 1 AS one FROM sushi AS sushi"
 
 
-def test_this(assert_exp_eq, sushi_dbt_project: Project):
+def test_this(assert_exp_eq, sushi_test_project: Project):
     model_config = ModelConfig(alias="test", sql="SELECT 1 AS one FROM {{ this.identifier }}")
-    context = sushi_dbt_project.context
+    context = sushi_test_project.context
     assert_exp_eq(
         model_config.to_sqlmesh(context).render_query().sql(), "SELECT 1 AS one FROM test AS test"
     )
 
 
-def test_statement(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_statement(sushi_test_project: Project):
+    context = sushi_test_project.context
     assert context.render(
         "{% set test_var = 'SELECT 1' %}{% call statement('something', fetch_result=True) %} {{ test_var }} {% endcall %}{{ load_result('something').table }}"
     ) == str(agate.Table([[1]], column_names=["1"], column_types=[agate.Number()]))
 
 
-def test_run_query(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_run_query(sushi_test_project: Project):
+    context = sushi_test_project.context
     assert context.render("{{ run_query('SELECT 1 UNION ALL SELECT 2') }}") == str(
         agate.Table([[1], [2]], column_names=["1"], column_types=[agate.Number()])
     )
 
 
-def test_logging(capsys, sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_logging(capsys, sushi_test_project: Project):
+    context = sushi_test_project.context
 
     assert context.render('{{ log("foo") }}') == ""
     assert "foo" in capsys.readouterr().out
@@ -283,8 +277,8 @@ def test_logging(capsys, sushi_dbt_project: Project):
     assert "bar" in capsys.readouterr().out
 
 
-def test_exceptions(capsys, sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_exceptions(capsys, sushi_test_project: Project):
+    context = sushi_test_project.context
 
     assert context.render('{{ exceptions.warn("Warning") }}') == ""
     assert "Warning" in capsys.readouterr().out
@@ -293,8 +287,8 @@ def test_exceptions(capsys, sushi_dbt_project: Project):
         context.render('{{ exceptions.raise_compiler_error("Error") }}')
 
 
-def test_modules(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_modules(sushi_test_project: Project):
+    context = sushi_test_project.context
 
     # datetime
     assert context.render("{{ modules.datetime.date(2022, 12, 25) }}") == "2022-12-25"
@@ -315,16 +309,16 @@ def test_modules(sushi_dbt_project: Project):
     assert context.render(itertools_jinja) == "5"
 
 
-def test_flags(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_flags(sushi_test_project: Project):
+    context = sushi_test_project.context
 
     assert context.render("{{ flags.FULL_REFRESH }}") == "None"
     assert context.render("{{ flags.STORE_FAILURES }}") == "None"
     assert context.render("{{ flags.WHICH }}") == "None"
 
 
-def test_relation(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_relation(sushi_test_project: Project):
+    context = sushi_test_project.context
 
     jinja = (
         "{% set relation = api.Relation.create(schema='sushi', identifier='waiters') %}"
@@ -334,8 +328,8 @@ def test_relation(sushi_dbt_project: Project):
     assert context.render(jinja) == "sushi waiters"
 
 
-def test_column(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_column(sushi_test_project: Project):
+    context = sushi_test_project.context
 
     jinja = (
         "{% set col = api.Column('foo', 'integer') %}" "{{ col.is_integer() }} {{ col.is_string()}}"
@@ -344,15 +338,15 @@ def test_column(sushi_dbt_project: Project):
     assert context.render(jinja) == "True False"
 
 
-def test_quote(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_quote(sushi_test_project: Project):
+    context = sushi_test_project.context
 
     jinja = "{{ adapter.quote('foo') }} {{ adapter.quote('bar') }}"
     assert context.render(jinja) == '"foo" "bar"'
 
 
-def test_as_filters(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_as_filters(sushi_test_project: Project):
+    context = sushi_test_project.context
 
     assert context.render("{{ True | as_bool }}") == "True"
     with pytest.raises(MacroEvalError, match="Failed to convert 'invalid' into boolean."):
@@ -367,8 +361,8 @@ def test_as_filters(sushi_dbt_project: Project):
     assert context.render("{{ None | as_native }}") == "None"
 
 
-def test_set(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_set(sushi_test_project: Project):
+    context = sushi_test_project.context
 
     assert context.render("{{ set([1, 1, 2]) }}") == "{1, 2}"
     assert context.render("{{ set(1) }}") == "None"
@@ -378,8 +372,8 @@ def test_set(sushi_dbt_project: Project):
         assert context.render("{{ set_strict(1) }}")
 
 
-def test_json(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_json(sushi_test_project: Project):
+    context = sushi_test_project.context
 
     assert context.render("{{ tojson({'key': 'value'}) }}") == """{"key": "value"}"""
     assert context.render("{{ tojson(set([1])) }}") == "None"
@@ -388,8 +382,8 @@ def test_json(sushi_dbt_project: Project):
     assert context.render("""{{ fromjson('invalid') }}""") == "None"
 
 
-def test_yaml(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_yaml(sushi_test_project: Project):
+    context = sushi_test_project.context
 
     assert context.render("{{ toyaml({'key': 'value'}) }}").strip() == "key: value"
     assert context.render("{{ toyaml(invalid) }}", invalid=lambda: "") == "None"
@@ -397,8 +391,8 @@ def test_yaml(sushi_dbt_project: Project):
     assert context.render("""{{ fromyaml('key: value') }}""") == "{'key': 'value'}"
 
 
-def test_zip(sushi_dbt_project: Project):
-    context = sushi_dbt_project.context
+def test_zip(sushi_test_project: Project):
+    context = sushi_test_project.context
 
     assert context.render("{{ zip([1, 2], ['a', 'b']) }}") == "[(1, 'a'), (2, 'b')]"
     assert context.render("{{ zip(12, ['a', 'b']) }}") == "None"
