@@ -1,11 +1,14 @@
 import asyncio
 from pathlib import Path
 
+import pyarrow as pa  # type: ignore
 import pytest
 from fastapi.testclient import TestClient
+from pytest_mock.plugin import MockerFixture
 
 from sqlmesh.core.context import Context
-from web.server.main import app
+from sqlmesh.utils.errors import PlanError
+from web.server.main import api_console, app
 from web.server.settings import Settings, get_loaded_context, get_settings
 
 client = TestClient(app)
@@ -27,6 +30,17 @@ config = Config()
     return tmp_path
 
 
+@pytest.fixture
+def project_context(project_tmp_path: Path) -> Context:
+    context = Context(path=str(project_tmp_path), console=api_console)
+
+    def get_loaded_context_override() -> Context:
+        return context
+
+    app.dependency_overrides[get_loaded_context] = get_loaded_context_override
+    return context
+
+
 @pytest.fixture
 def web_sushi_context(sushi_context: Context) -> Context:
     def get_context_override() -> Context:
@@ -59,6 +73,7 @@ def test_get_files(project_tmp_path: Path) -> None:
                         "extension": ".sql",
                         "is_supported": True,
                         "content": None,
+                        "type": "model",
                     }
                 ],
             }
@@ -70,6 +85,7 @@ def test_get_files(project_tmp_path: Path) -> None:
                 "extension": ".py",
                 "is_supported": True,
                 "content": None,
+                "type": None,
             }
         ],
     }
@@ -87,6 +103,7 @@ def test_get_file(project_tmp_path: Path) -> None:
         "extension": ".txt",
         "is_supported": False,
         "content": "bar",
+        "type": None,
     }
 
 
@@ -118,6 +135,7 @@ def test_write_file(project_tmp_path: Path) -> None:
         "extension": ".txt",
         "is_supported": False,
         "content": "bar",
+        "type": None,
     }
     assert (project_tmp_path / "foo.txt").read_text() == "bar"
 
@@ -134,6 +152,7 @@ def test_update_file(project_tmp_path: Path) -> None:
         "extension": ".txt",
         "is_supported": False,
         "content": "baz",
+        "type": None,
     }
     assert (project_tmp_path / "foo.txt").read_text() == "baz"
 
@@ -150,12 +169,13 @@ def test_rename_file(project_tmp_path: Path) -> None:
         "extension": ".txt",
         "is_supported": False,
         "content": "bar",
+        "type": None,
     }
     assert not txt_file.exists()
     assert (project_tmp_path / "baz.txt").read_text() == "bar"
 
 
-def test_rename_and_update_file(project_tmp_path: Path) -> None:
+def test_rename_file_and_keep_content(project_tmp_path: Path) -> None:
     txt_file = project_tmp_path / "foo.txt"
     txt_file.write_text("bar")
 
@@ -168,13 +188,14 @@ def test_rename_and_update_file(project_tmp_path: Path) -> None:
         "path": "baz.txt",
         "extension": ".txt",
         "is_supported": False,
-        "content": "hello world",
+        "content": "bar",
+        "type": None,
     }
     assert not txt_file.exists()
-    assert (project_tmp_path / "baz.txt").read_text() == "hello world"
+    assert (project_tmp_path / "baz.txt").read_text() == "bar"
 
 
-def test_rename_file_not_found(project_tmp_path: Path) -> None:
+def test_rename_file_not_found() -> None:
     response = client.post("/api/files/foo.txt", json={"new_path": "baz.txt"})
     assert response.status_code == 404
 
@@ -193,6 +214,7 @@ def test_rename_file_already_exists(project_tmp_path: Path) -> None:
         "extension": ".txt",
         "is_supported": False,
         "content": "foo",
+        "type": None,
     }
     assert not foo_file.exists()
 
@@ -208,9 +230,17 @@ def test_rename_file_to_existing_directory(project_tmp_path: Path) -> None:
     assert foo_file.exists()
 
 
-def test_write_file_empty_body(project_tmp_path: Path) -> None:
+def test_write_file_empty_body() -> None:
     response = client.post("/api/files/foo.txt", json={})
-    assert response.status_code == 404
+    assert response.status_code == 200
+    assert response.json() == {
+        "name": "foo.txt",
+        "path": "foo.txt",
+        "extension": ".txt",
+        "is_supported": False,
+        "content": "",
+        "type": None,
+    }
 
 
 def test_delete_file(project_tmp_path: Path) -> None:
@@ -334,14 +364,37 @@ def test_delete_directory_not_empty(project_tmp_path: Path) -> None:
     assert not new_dir.exists()
 
 
-def test_apply() -> None:
-    response = client.post("/api/apply?environment=dev", params={"environment": "dev"})
+def test_apply(project_tmp_path: Path) -> None:
+    models_dir = project_tmp_path / "models"
+    models_dir.mkdir()
+    sql_file = models_dir / "foo.sql"
+    sql_file.write_text("MODEL (name foo); SELECT 1;")
+
+    response = client.post("/api/commands/apply", json={"environment": "dev"})
     assert response.status_code == 200
 
 
-def test_tasks() -> None:
-    response = client.get("/api/tasks")
+def test_apply_test_failures(web_sushi_context: Context, mocker: MockerFixture) -> None:
+    mocker.patch.object(web_sushi_context, "_run_plan_tests", side_effect=PlanError("foo"))
+    response = client.post("/api/commands/apply", json={"environment": "dev"})
+    assert response.status_code == 422
+    assert response.json()["detail"] == "foo"
+
+
+def test_plan(web_sushi_context: Context) -> None:
+    response = client.post("/api/plan", json={"environment": "dev"})
     assert response.status_code == 200
+    plan = response.json()
+    assert plan["environment"] == "dev"
+    assert "backfills" in plan
+    assert "changes" in plan
+
+
+def test_plan_test_failures(web_sushi_context: Context, mocker: MockerFixture) -> None:
+    mocker.patch.object(web_sushi_context, "_run_plan_tests", side_effect=PlanError("foo"))
+    response = client.post("/api/plan", json={"environment": "dev"})
+    assert response.status_code == 422
+    assert response.json()["detail"] == "foo"
 
 
 @pytest.mark.asyncio
@@ -361,7 +414,7 @@ def test_cancel_no_task() -> None:
 
 def test_evaluate(web_sushi_context: Context) -> None:
     response = client.post(
-        "/api/evaluate",
+        "/api/commands/evaluate",
         json={
             "model": "sushi.top_waiters",
             "start": "2022-01-01",
@@ -371,10 +424,48 @@ def test_evaluate(web_sushi_context: Context) -> None:
         },
     )
     assert response.status_code == 200
-    assert response.json()
+    with pa.ipc.open_stream(response.content) as reader:
+        df = reader.read_pandas()
+    assert not df.empty
 
 
 def test_fetchdf(web_sushi_context: Context) -> None:
-    response = client.post("/api/fetchdf", json={"sql": "SELECT * from sushi.top_waiters"})
+    response = client.post("/api/commands/fetchdf", json={"sql": "SELECT * from sushi.top_waiters"})
     assert response.status_code == 200
-    assert response.json()
+    with pa.ipc.open_stream(response.content) as reader:
+        df = reader.read_pandas()
+    assert not df.empty
+
+
+def test_get_models(web_sushi_context: Context) -> None:
+    response = client.get("/api/models")
+    assert response.status_code == 200
+    assert response.json()["models"].keys() == web_sushi_context.models.keys()
+
+
+def test_render(web_sushi_context: Context) -> None:
+    response = client.post("/api/commands/render", json={"model": "sushi.items"})
+    assert response.status_code == 200
+    assert response.json()["sql"]
+
+
+def test_render_invalid_model(web_sushi_context: Context) -> None:
+    response = client.post("/api/commands/render", json={"model": "foo.bar"})
+    assert response.status_code == 422
+    assert response.json() == {"detail": "Model not found."}
+
+
+def test_get_environments(project_context: Context) -> None:
+    response = client.get("/api/environments")
+    assert response.status_code == 200
+    assert response.json() == {
+        "prod": {
+            "name": "prod",
+            "snapshots": [],
+            "start_at": 0,
+            "end_at": None,
+            "plan_id": "",
+            "previous_plan_id": None,
+            "expiration_ts": None,
+        }
+    }
