@@ -1,13 +1,11 @@
-import { useCallback, useEffect, useMemo, useRef, useState } from 'react'
+import { useCallback, useEffect, useRef, useState } from 'react'
+import { debounceAsync, includes, isFalse } from '~/utils'
 import {
-  debounceAsync,
-  includes,
-  isFalse,
-  isStringEmptyOrNil,
-  toDate,
-  toDateFormat,
-} from '~/utils'
-import { EnumPlanState, EnumPlanAction, useStorePlan, EnumPlanApplyType } from '~/context/plan'
+  EnumPlanState,
+  EnumPlanAction,
+  useStorePlan,
+  EnumPlanApplyType,
+} from '~/context/plan'
 import { Divider } from '~/library/components/divider/Divider'
 import {
   useApiPlanRun,
@@ -16,7 +14,6 @@ import {
   apiCancelPlanApply,
 } from '~/api'
 import {
-  type BodyApplyApiCommandsApplyPostCategories,
   type ContextEnvironmentEnd,
   type ContextEnvironmentStart,
 } from '~/api/client'
@@ -28,6 +25,7 @@ import { EnumPlanActions, usePlan, usePlanDispatch } from './context'
 import PlanBackfillDates from './PlanBackfillDates'
 import { isCancelledError, useQueryClient } from '@tanstack/react-query'
 import { type ModelEnvironment } from '~/models/environment'
+import { useApplyPayload, usePlanPayload } from './hooks'
 
 function Plan({
   environment,
@@ -47,22 +45,7 @@ function Plan({
   const client = useQueryClient()
 
   const dispatch = usePlanDispatch()
-  const {
-    start,
-    end,
-    skip_tests,
-    no_gaps,
-    skip_backfill,
-    forward_only,
-    auto_apply,
-    no_auto_categorization,
-    restate_models,
-    hasChanges,
-    hasBackfills,
-    hasVirtualUpdate,
-    create_from,
-    change_categorization,
-  } = usePlan()
+  const { auto_apply, hasChanges, hasBackfills, hasVirtualUpdate } = usePlan()
 
   const planState = useStorePlan(s => s.state)
   const planAction = useStorePlan(s => s.action)
@@ -75,80 +58,11 @@ function Plan({
   const [isPlanRan, seIsPlanRan] = useState(false)
   const [error, setError] = useState<Error>()
 
-  const { refetch: planRun } = useApiPlanRun(environment.name, {
-    planDates: environment.isDefault
-      ? undefined
-      : {
-        start,
-        end:
-          isInitialPlanRun || isStringEmptyOrNil(restate_models)
-            ? undefined
-            : end,
-      },
-    planOptions: environment.isInitial
-      ? {
-        skip_tests: true,
-      }
-      : environment.isDefault
-        ? {
-          skip_tests,
-        }
-        : {
-          no_gaps,
-          skip_backfill,
-          forward_only,
-          create_from,
-          no_auto_categorization,
-          skip_tests,
-          restate_models,
-        },
-  })
+  const planPayload = usePlanPayload({ environment, isInitialPlanRun })
+  const applyPayload = useApplyPayload({ isInitialPlanRun })
 
-  const { refetch: planApply } = useApiPlanApply(environment.name, {
-    planDates:
-      hasBackfills && isFalse(isInitialPlanRun)
-        ? {
-          start,
-          end,
-        }
-        : undefined,
-    planOptions: {
-      no_gaps,
-      skip_backfill,
-      forward_only,
-      create_from,
-      no_auto_categorization,
-      skip_tests,
-      restate_models,
-    },
-    categories: Array.from(
-      change_categorization.values(),
-    ).reduce<BodyApplyApiCommandsApplyPostCategories>(
-      (acc, { category, change }) => {
-        acc[change.model_name] = category.value
-
-        return acc
-      },
-      {},
-    ),
-  })
-
-  const [startDate, endDate] = useMemo(() => {
-    const ONE_DAY = 1000 * 60 * 60 * 24
-    const end = isInitialPlanRun
-      ? initialEndDate
-      : toDateFormat(new Date(), 'mm/dd/yyyy')
-    const dateinitialEndDate = toDate(end)
-    const oneDayOffinitialEndDate =
-      dateinitialEndDate == null
-        ? undefined
-        : new Date(dateinitialEndDate.getTime() - ONE_DAY)
-    const start = isInitialPlanRun
-      ? initialStartDate
-      : toDateFormat(oneDayOffinitialEndDate, 'mm/dd/yyyy')
-
-    return [start, end]
-  }, [isInitialPlanRun, initialStartDate, initialEndDate])
+  const { refetch: planRun } = useApiPlanRun(environment.name, planPayload)
+  const { refetch: planApply } = useApiPlanApply(environment.name, applyPayload)
 
   const debouncedPlanRun = useCallback(debounceAsync(planRun, 1000, true), [
     planRun,
@@ -159,6 +73,14 @@ function Plan({
       run()
     }
 
+    dispatch([
+      {
+        type: EnumPlanActions.Dates,
+        start: initialStartDate,
+        end: initialEndDate,
+      },
+    ])
+
     return () => {
       debouncedPlanRun.cancel()
 
@@ -172,11 +94,6 @@ function Plan({
         type: EnumPlanActions.External,
         isInitialPlanRun,
       },
-      {
-        type: EnumPlanActions.Dates,
-        start: startDate,
-        end: endDate,
-      },
     ])
 
     if (isInitialPlanRun) {
@@ -190,7 +107,7 @@ function Plan({
         },
       ])
     }
-  }, [isInitialPlanRun, initialStartDate, initialEndDate])
+  }, [isInitialPlanRun])
 
   useEffect(() => {
     if (
@@ -239,8 +156,8 @@ function Plan({
       },
       {
         type: EnumPlanActions.Dates,
-        start: startDate,
-        end: endDate,
+        start: initialStartDate,
+        end: initialEndDate,
       },
       {
         type: EnumPlanActions.ResetPlanOptions,
