@@ -12,7 +12,6 @@ import {
   type PlanTaskStatus,
 } from '../../../context/plan'
 import {
-  includes,
   isArrayEmpty,
   isArrayNotEmpty,
   isFalse,
@@ -123,10 +122,6 @@ export default function PlanWizard({
     [backfills, change_categorization, activeBackfill],
   )
 
-  const isProgress = includes(
-    [EnumPlanState.Cancelling, EnumPlanState.Applying],
-    planState,
-  )
   const isFinished = planState === EnumPlanState.Finished
   const hasNoChanges = [
     hasChanges,
@@ -216,7 +211,7 @@ export default function PlanWizard({
                     )}
                     {isArrayNotEmpty(modified?.metadata) && (
                       <PlanChangePreview
-                      className="w-full my-2"
+                        className="w-full my-2"
                         headline="Modified Metadata"
                         type={EnumPlanChangeType.Metadata}
                       >
@@ -260,11 +255,11 @@ export default function PlanWizard({
                         <h3
                           className={clsx(
                             planState === EnumPlanState.Cancelled &&
-                            'text-prose',
+                              'text-prose',
                             planState === EnumPlanState.Failed &&
-                            'text-danger-700',
+                              'text-danger-700',
                             planState === EnumPlanState.Finished &&
-                            'text-success-700',
+                              'text-success-700',
                           )}
                         >
                           {backfillStepHeadline}
@@ -308,11 +303,6 @@ export default function PlanWizard({
                               setRefTaskProgress={setRefTaskProgress}
                             />
                           </Suspense>
-                          <form>
-                            <fieldset className="flex w-full">
-                              <Plan.BackfillDates disabled={isProgress} />
-                            </fieldset>
-                          </form>
                         </>
                       )}
                     {hasVirtualUpdate && (
