@@ -8,14 +8,14 @@ export interface PropsProgress extends React.HTMLAttributes<HTMLElement> {
 
 export default function Progress({
   progress = 0,
-  delay = 150,
-  duration = 500,
+  delay = 0,
+  duration = 0,
   className,
 }: PropsProgress): JSX.Element {
   return (
     <div
       className={clsx(
-        'w-full h-1 bg-gray-100 overflow-hidden flex items-center rounded-lg my-1',
+        'w-full h-1 bg-neutral-30 overflow-hidden flex items-center rounded-lg my-1',
         className,
       )}
     >
