@@ -1,7 +1,7 @@
 from fastapi import APIRouter, Depends
 
 from sqlmesh.core.context import Context
-from web.server.models import Model, Models
+from web.server.models import Column, Model, Models
 from web.server.settings import get_loaded_context
 
 router = APIRouter()
@@ -18,6 +18,13 @@ def get_models(
             path=str(model._path.relative_to(context.path)),
             description=model.description,
             owner=model.owner,
+            dialect=model.dialect,
+            columns=[
+                Column(
+                    name=name, type=str(data_type), description=model.column_descriptions.get(name)
+                )
+                for name, data_type in model.columns_to_types.items()
+            ],
         )
         for model in context.models.values()
     }
